==> cv-library-react-web-0.1.10.tgz: package/src/components/DropDown/DropDown.js <==
import React, { forwardRef, useState } from 'react';
import PropTypes from 'prop-types';
import { Select, FormControl } from '@material-ui/core';

import { makeStyles } from '@material-ui/core/styles';
import getStyles from './DropDown.styles';

import MenuItem from '../MenuItem/MenuItem';

/**
 * Dropdown component that allows a user to select an option from a pre-defined menu of options.
 * @see https://material-ui.com/demos/selects/
 */
const DropDown = (props) => {
    const {
        contextStyles,
        items,
        disabled,
        testID,
        value,
        onChange,
        renderItem,
        renderValue,
        autoFocus,
    } = props;

    const [
        open,
        setOpen,
    ] = useState(!!autoFocus);

    // Override core styles with context styles, separating MUI styles
    const {
        menuItem: menuItemStyles,
        selectedItem: selectedMenuItemStyles,
        ...muiStyles
    } = getStyles(contextStyles);

    // Create dynamic class names and injected DOM styles for MUI component
    // * makeStyles returns a function
    const styles = makeStyles(muiStyles)();

    // Generate container props
    const containerProps = {
        classes: {
            root: styles.container,
        },
        className: 'c-drop-down__container',
    };
    if (testID) { containerProps['data-test-id'] = `${testID}__drop-down__container`; }

    // Generate select props
    const selectProps = {
        classes: {
            root: styles.dropDown,
            icon: styles.icon,
        },
        className: 'c-drop-down__menu',
        disabled,
        MenuProps: {
            classes: {
                paper: styles.menu,
            },
        },
        onChange,
        renderValue,
        value,
        open,
        onClose: () => setOpen(false),
        onOpen: () => setOpen(true),
    };
    if (testID) { selectProps['data-test-id'] = `${testID}__drop-down__menu`; }

    // Generate menu item props
    const itemProps = {
        className: 'c-drop-down__menu-item',
        contextStyles: {
            container: menuItemStyles,
            selected: selectedMenuItemStyles,
        },
    };
    if (testID) { itemProps.testID = `${testID}__drop-down__menu-item`; }

    // Create menu item with base props used to create this menu instance
    // eslint-disable-next-line react/display-name
    const CustomMenuItem = forwardRef((cProps, ref) => (
        <MenuItem
            ref={ ref }
            { ...itemProps }
            { ...cProps }
            selected={ cProps.text === value } />
    ));

    return (
        <FormControl { ...containerProps }>
            <Select { ...selectProps }>
                { items.length === 0 && (
                    <MenuItem
                        onClick={ () => null }
                        text="(empty)" />
                ) }
                { items.map((item) => renderItem(CustomMenuItem, item)) }
            </Select>
        </FormControl>
    );
};

DropDown.propTypes = {
    /** Auto focus the dropdown menu */
    autoFocus: PropTypes.bool,

    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,

        /** Styles for the menu */
        menu: PropTypes.object,

        /** Styles for each menu option */
        menuItem: PropTypes.object,

        /** Styles for the Selected Item in the menu */
        selectedItem: PropTypes.object,
    }),

    /** Disable the dropdown */
    disabled: PropTypes.bool,

    /** An array of drop down menu items */
    items: PropTypes.array,

    /**
     * Called when change event occurs on the dropdown
     * @param {Event} event - The change event
     */
    onChange: PropTypes.func.isRequired,

    /**
     * Called to render the menu items
     * @param {Component} MenuItem - The default menu item component
     * @param {any} Item - Item that needs to be rendered
     */
    renderItem: PropTypes.func.isRequired,

    /**
     * Function that is used to render a custom selected option
     * @param {any} value - The current selected item.
     */
    renderValue: PropTypes.func.isRequired,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Selected Item value */
    value: PropTypes.string,
};

DropDown.defaultProps = {
    contextStyles: {},
    value: '',
    items: [],
};

export default DropDown;

==> cv-library-react-web-0.1.19.tgz: package/src/components/DropDown/DropDown.js <==
import React, { Fragment, forwardRef, useState, useEffect } from 'react';
import PropTypes from 'prop-types';
import { Select, FormControl } from '@material-ui/core';

import { makeStyles } from '@material-ui/core/styles';
import getStyles from './DropDown.styles';

import MenuItem from '../MenuItem/MenuItem';
import ActivityIndicator from '../ActivityIndicator/ActivityIndicator';

/**
 * Dropdown component that allows a user to select an option from a pre-defined menu of options.
 * @see https://material-ui.com/demos/selects/
 */
const DropDown = (props) => {
    const {
        contextStyles,
        items: initialItems,
        itemsResolver: getData,
        disabled,
        testID,
        value,
        onChange,
        renderItem,
        renderValue,
        autoFocus,
    } = props;

    const [
        open,
        setOpen,
    ] = useState(!!autoFocus);
    const [
        items,
        setItems,
    ] = useState(initialItems);
    const [
        loading,
        setLoading,
    ] = useState(false);
    useEffect(() => {
        setItems(initialItems);
    }, [ initialItems ]);

    // Override core styles with context styles, separating MUI styles
    const {
        menuItem: menuItemStyles,
        selectedItem: selectedMenuItemStyles,
        ...muiStyles
    } = getStyles(contextStyles);

    // Create dynamic class names and injected DOM styles for MUI component
    // * makeStyles returns a function
    const styles = makeStyles(muiStyles)();

    // Generate container props
    const containerProps = {
        classes: {
            root: styles.container,
        },
        className: 'c-drop-down__container',
    };
    if (testID) { containerProps['data-test-id'] = `${testID}__drop-down__container`; }

    // Generate select props
    const selectProps = {
        classes: {
            root: styles.dropDown,
            icon: styles.icon,
        },
        className: 'c-drop-down__menu',
        disabled,
        MenuProps: {
            classes: {
                paper: styles.menu,
            },
        },
        onChange,
        renderValue,
        value,
        open,
        onClose: () => setOpen(false),
        onOpen: () => {
            // Handle dynamic items generation
            if (getData) {
                setLoading(true);
                Promise.resolve(getData())
                    .then((data) => {
                        setItems(data);
                        setLoading(false);
                        setOpen(true);
                    });
            }
            else {
                setOpen(true);
            }
        },
    };

    // Handle dynamic loading state
    if (loading) {
        // Generate indicator props
        const indicatorProps = {
            contextStyles: { container: { marginRight: '0.5rem' } },
            size: 15,
        };

        // Disable control to prevent interaction while loading
        selectProps.disabled = true;

        // Inject an activity indicator before the value display
        selectProps.renderValue = (...args) => ( // eslint-disable-line react/display-name
            <Fragment>
                <ActivityIndicator { ...indicatorProps } />
                { renderValue && renderValue(...args) }
            </Fragment>
        );
    }
    if (testID) { selectProps['data-test-id'] = `${testID}__drop-down__menu`; }

    // Generate menu item props
    const itemProps = {
        className: 'c-drop-down__menu-item',
        contextStyles: {
            container: menuItemStyles,
            selected: selectedMenuItemStyles,
        },
    };
    if (testID) { itemProps.testID = `${testID}__drop-down__menu-item`; }

    // Create menu item with base props used to create this menu instance
    // eslint-disable-next-line react/display-name
    const CustomMenuItem = forwardRef((cProps, ref) => (
        <MenuItem
            ref={ ref }
            { ...itemProps }
            { ...cProps }
            selected={ cProps.text === value } />
    ));

    return (
        <FormControl { ...containerProps }>
            <Select { ...selectProps }>
                { items && items.length === 0 && (
                    <MenuItem
                        onClick={ () => null }
                        text="(empty)" />
                ) }
                { items && items.map((item) => renderItem(CustomMenuItem, item)) }
            </Select>
        </FormControl>
    );
};

DropDown.propTypes = {
    /** Auto focus the dropdown menu */
    autoFocus: PropTypes.bool,

    /** Styles for this component */
    contextStyles: PropTypes.shape({
        /** Styles for the container */
        container: PropTypes.object,

        /** Styles for the menu */
        menu: PropTypes.object,

        /** Styles for each menu option */
        menuItem: PropTypes.object,

        /** Styles for the Selected Item in the menu */
        selectedItem: PropTypes.object,
    }),

    /** Disable the dropdown */
    disabled: PropTypes.bool,

    /** An array of drop down menu items */
    items: PropTypes.array,

    /**
     * Return a method that resolves to 'items' prop
     * @return {Array<{data: *, icon: String, text: String}>}
     */
    itemsResolver: PropTypes.func,

    /**
     * Called when change event occurs on the dropdown
     * @param {Event} event - The change event
     */
    onChange: PropTypes.func.isRequired,

    /**
     * Called to render the menu items
     * @param {Component} MenuItem - The default menu item component
     * @param {any} Item - Item that needs to be rendered
     */
    renderItem: PropTypes.func.isRequired,

    /**
     * Function that is used to render a custom selected option
     * @param {any} value - The current selected item.
     */
    renderValue: PropTypes.func.isRequired,

    /** Id used for testing */
    testID: PropTypes.string,

    /** Selected Item value */
    value: PropTypes.string,
};

DropDown.defaultProps = {
    contextStyles: {},
    value: '',
    items: [],
};

export default DropDown;
